---
name: Bug Report
about: Report something that isn't working correctly
title: 'fix: '
labels: bug
assignees: ''

---

## What is happening?
- [ ] **Expected:** 
- [ ] **Actual:** 

### Expected

### Actual

## Environment?
- [ ] OS? Windows/Mac/Linux
- [ ] Version/Commit? v0.1.0

## How to reproduce?
- [ ] Reproduce steps:
  1.
  2. 

## Why? (Root Cause Analysis) # optional
- [ ] Potential culprit: `file_path_or_function`
- [ ] Error messages/Logs:
  ```text
  paste error here
  ```

## How to Fix? (Rough Planning) # optional
- [ ] Fixing steps:
  1.
  2.
